==> tekton-model-triggers-v1alpha1-6.6.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerBindingListFluent<A extends TriggerBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,TriggerBinding item);
  public A setToItems(Integer index,TriggerBinding item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A addAllToItems(Collection<TriggerBinding> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A removeAllFromItems(Collection<TriggerBinding> items);
  public A removeMatchingFromItems(Predicate<TriggerBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerBinding> getItems();
  public List<TriggerBinding> buildItems();
  public TriggerBinding buildItem(Integer index);
  public TriggerBinding buildFirstItem();
  public TriggerBinding buildLastItem();
  public TriggerBinding buildMatchingItem(Predicate<TriggerBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<TriggerBindingBuilder> predicate);
  public A withItems(List<TriggerBinding> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public Boolean hasItems();
  public TriggerBindingListFluent.ItemsNested<A> addNewItem();
  public TriggerBindingListFluent.ItemsNested<A> addNewItemLike(TriggerBinding item);
  public TriggerBindingListFluent.ItemsNested<A> setNewItemLike(Integer index,TriggerBinding item);
  public TriggerBindingListFluent.ItemsNested<A> editItem(Integer index);
  public TriggerBindingListFluent.ItemsNested<A> editFirstItem();
  public TriggerBindingListFluent.ItemsNested<A> editLastItem();
  public TriggerBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<TriggerBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,TriggerBindingFluent<TriggerBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerBindingListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface TriggerBindingListFluent<A extends TriggerBindingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,TriggerBinding item);
  public A setToItems(int index,TriggerBinding item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A addAllToItems(Collection<TriggerBinding> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A removeAllFromItems(Collection<TriggerBinding> items);
  public A removeMatchingFromItems(Predicate<TriggerBindingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TriggerBinding> getItems();
  public List<TriggerBinding> buildItems();
  public TriggerBinding buildItem(int index);
  public TriggerBinding buildFirstItem();
  public TriggerBinding buildLastItem();
  public TriggerBinding buildMatchingItem(Predicate<TriggerBindingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<TriggerBindingBuilder> predicate);
  public A withItems(List<TriggerBinding> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public Boolean hasItems();
  public TriggerBindingListFluent.ItemsNested<A> addNewItem();
  public TriggerBindingListFluent.ItemsNested<A> addNewItemLike(TriggerBinding item);
  public TriggerBindingListFluent.ItemsNested<A> setNewItemLike(int index,TriggerBinding item);
  public TriggerBindingListFluent.ItemsNested<A> editItem(int index);
  public TriggerBindingListFluent.ItemsNested<A> editFirstItem();
  public TriggerBindingListFluent.ItemsNested<A> editLastItem();
  public TriggerBindingListFluent.ItemsNested<A> editMatchingItem(Predicate<TriggerBindingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,TriggerBindingFluent<TriggerBindingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
